# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-09-29 09:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0071_remove_old_image_hashes'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='fb_analytics_app_id',
            field=models.CharField(blank=True, help_text='The tracking ID to be used to view Facebook Analytics', max_length=25, null=True, verbose_name='Facebook Analytics App ID'),
        ),
    ]
