# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-05-17 16:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0001_squashed_0021_remove_uuid_null'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='auth_service_uuid',
            field=models.UUIDField(null=True, unique=True),
        ),
    ]
