 
{% load i18n %}

{% block content %}
	<div class="title profile">
		<h3>{% trans "Sign in" %}</h3>
	</div>

	<div class="block turq">
		<div class="signin-form">
			<h5>{% trans "LOGIN TO YOUR ACCOUNT!" %}</h5>
			<p>{% trans "We’re excited to have you..." %}</p>
	    <form method="post" action=".">{% csrf_token %}
	        {% if form.errors %}
	            <p class="error errorlist">{% trans "Your username and password does not match. Please try again." %}</p>
	        {% endif %}
					<p><strong>{% trans "Username" %}</strong></p>
					{{form.username}}
					<p><strong>{% trans "4-digit pin" %}</strong></p>
					{{form.password}}
					<input type="submit" value="{% trans 'Sign in' %}">
					<input type="hidden" name="next" value="{% if request.GET.next %}{{ request.GET.next }}{% else %}{{request.site.root_page.url}}{% endif %}" />
	    </form>
		</div>
		<a href="{% url 'password_reset' %}">{% trans 'Forgotten your password?' %}</a>
	</div>
{% endblock %}
 
