{% load wagtailcore_tags core_tags  %}
<h2 class="heading heading-section-article heading-section-article{{hintstyle}}">
  <a href="{% pageurl section %}" class="heading-section-article__link">{{section.title}}</a>
</h2>
<span class="article-back">
  <a href="{% pageurl section %}" class="article-back__anchor article-back__anchor{{section.get_effective_extra_style_hints}}">Back</a>
</span>
