{% load wagtailcore_tags core_tags i18n %}
{% if settings.core.SiteSettings.enable_clickable_tags %}
<div class="tags">
  <ul class="tags-list">
    {% for tag in self.tags_list %}
    <li class="tags-list__item">
      <a href="#" class="tags-list__item-anchor">
          {{tag}}
      </a>
    </li>
  {% endfor %}
  </ul>
</div>
{% endif %}
