@function scale($key, $unit: "rem") {
    $scale: map-get($scale, $key);

    @if $enhanced == true {
        @if $unit == "rem" {
            @return rem($scale);
        } @elseif $unit == "em" {
            @return em($scale);
        }
    } @else {
        @return unquote("#{$scale}px");
    }
}
