# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2016-11-17 08:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0047_add_core_permissions_to_groups'),
    ]

    operations = [
        migrations.AddField(
            model_name='articlepage',
            name='featured_in_homepage_end_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='featured_in_homepage_start_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='featured_in_latest_end_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='featured_in_latest_start_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='featured_in_section_end_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='featured_in_section_start_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
