.section-listing {
    &__title {
        padding: 10px 15px;
        @include heading-scale($heading-xx-large);
        &-theme-headings {
          color: #000;
          border-top-style: dotted;
          border-top-width: 1px;
          padding: 5px 15px;
          font-size: $font-small;
          @include heading-scale($heading-xx-large);
        }
        &-theme-general,
        &-theme-standard {
            color: #000;
            padding: 0 10px;
            @include heading-scale($heading-xx-large);
        }
    }
    &__theme-bg-title {
        padding: 10px 15px;
        @include heading-scale($heading-xx-large);
    }
    &__theme-subsection_bg-title {
        padding: 5px 15px;
        @include heading-scale($heading-xx-large);
    }
    &__theme-more-link {
        display: block;
        padding: 10px 15px;
        font-weight: bold;
        &:after {
          padding: 0 0 0 10px;
          @media screen and (min-width: 320px) {
            content: ">";
          }
          @media screen and (min-width: 490px) {
            content: "❯";
          }
        }
        &:hover {
          text-decoration: none;
          opacity: 0.5;
        }
    }
    &--mote {
      padding: 10px 0;
    }
    &__link {
        color: #dc5a11;
        &-theme-headings {
            color: #000;
            @include heading-scale($heading-xx-large);
        }
    }
    &-latest {
        &__title {
          padding: 10px 15px;
          @include heading-scale($heading-xx-large);
        }
    }
}
