.footer {
    &-alternate-menu {
      background: #fff;
      overflow: auto;
      @media screen and (min-width: 320px) {
        border-top: 1px solid #E5E7E9;
        padding: 20px 30px;
      }
      &:first-child {
        border-top: 1px solid #000;
      }

      &__item {
        display: block;
        padding: 5px 0;
      }

      &__anchor {
        color: #000;
        padding: 5px 0;
        @media screen and (min-width: 320px) {
          text-decoration: none;
        }
      }

      &__left-column {
        @media screen and (min-width: 320px) {
          float: left;
          clear: left;
          width: 40%;
        }
      }

      &__right-column {
        @media screen and (min-width: 320px) {
          float: right;
          clear: right;
          width: 45%;
        }
      }

    }
}
