# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-09-19 09:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0069_add_image_info'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='enable_service_directory',
            field=models.BooleanField(default=False, verbose_name=b'Enable service directory'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='google_places_api_server_key',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='google places server key'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='service_directory_api_base_url',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='service directory base url'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='service_directory_api_password',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='service directory password'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='service_directory_api_username',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='service directory username'),
        ),
    ]
