{% load i18n %}
{% block search_button %}
  <input placeholder="{% trans "Looking for something?" %}" name="q" type="text" value="{{search_query}}" id="input__{{radius}}">
  <input type="submit" value="{% trans "Search"%}" class="call-to-action__item call-to-action__item--with-icon call-to-action__item--search-icon">
{% endblock %}
